@@ -2,6 +2,7 @@ use strict;
 use warnings;
 
 package Net::Google::PicasaWeb::Album;
+our $VERSION = '0.07';
 use Moose;
 
 extends 'Net::Google::PicasaWeb::MediaFeed';
@@ -12,6 +13,10 @@ use Net::Google::PicasaWeb::Media;
 
 Net::Google::PicasaWeb::Album - represents a single Picasa Web photo album
 
+=head1 VERSION
+
+version 0.07
+
 =head1 SYNOPSIS
 
   my @albums = $service->list_albums;
@@ -49,8 +54,42 @@ This is the URL to get to the author's public albums on Picasa Web.
 
 This is a link to the L<Net::Google::PicasaWeb::Media> object that is used to reference the cover photo and thumbnails of it.
 
+=head2 bytes_used
+
+This is the size of the album in bytes.
+
+=cut
+
+has bytes_used => (
+    is => 'rw',
+    isa => 'Int',
+);
+
+=head2 number_of_photos
+
+This is the number of photos in the albums.
+
+=cut
+
+has number_of_photos => (
+    is => 'rw',
+    isa => 'Int',
+);
+
 =head1 METHODS
 
+=cut
+
+override from_feed => sub {
+    my ($class, $service, $entry) = @_;
+    my $self = $class->super($service, $entry);
+
+    $self->bytes_used($entry->field('gphoto:bytesUsed'));
+    $self->number_of_photos($entry->field('gphoto:numphotos'));
+
+    return $self;
+};
+
 =head2 list_media_entries
 
 =head2 list_photos
@@ -114,4 +153,4 @@ under the same terms as Perl itself.
 
 =cut
 
-1;
+1;
\ No newline at end of file
