@@ -2,6 +2,7 @@ use strict;
 use warnings;
 
 package Net::Google::PicasaWeb::Base;
+our $VERSION = '0.07';
 use Moose;
 
 with 'MooseX::Role::Matcher' => { default_match => 'id' };
@@ -10,6 +11,10 @@ with 'MooseX::Role::Matcher' => { default_match => 'id' };
 
 Net::Google::PicasaWeb::Base - base class
 
+=head1 VERSION
+
+version 0.07
+
 =head1 DESCRIPTION
 
 This defines some common tools available to many of the classes included with L<Net::Google::PicasaWeb>.
@@ -28,7 +33,7 @@ has service => (
     is => 'rw',
     isa => 'Net::Google::PicasaWeb',
     required => 1,
-    weaken => 1,
+    weak_ref => 1,
 );
 
 =head2 twig
@@ -57,4 +62,4 @@ under the same terms as Perl itself.
 
 =cut
 
-1;
+1;
\ No newline at end of file
